@@ -51,7 +51,7 @@ class ImageRequest:
             return False
 
         if 'content-type' in self.client.headers and self.client.headers['content-type']:
-            return self.client.headers['content-type'].lower()
+            return self.client.headers['content-type'].split(';')[0].lower()
         else:
             try:
                 return Magic(mime=True).from_buffer(self.get_content()).lower()
@@ -114,7 +114,7 @@ class Image(ImageRequest):
         self.resize_except = resize_except
 
         if self.client and self.client.status_code == 200:
-            if self.get_content_type() in self._allowed_types:
+            if self.get_content_type().split(';')[0] in self._allowed_types:
                 self._set_properties()
 
                 if max_width:
@@ -136,6 +136,7 @@ class Image(ImageRequest):
             self.size = self.get_content_length()
             self.extension = self.mime_to_extension(self.mime)
         except OSError as e:
+            self._is_valid = False
             print('OSError received while fetching image: ', self.url, e)
 
     def is_valid(self):
